;; Generated package description from casual.el  -*- mode: lisp-data; no-byte-compile: t; lexical-binding:t -*-
(define-package "casual" "2.17.1" "Transient user interfaces for various modes" '((emacs "30.1") (transient "0.9.0") (csv-mode "1.27")) :commit "cadbeab2ec45804e63a328202c9a82fbed2413c5" :authors '(("Charles Choi" . "kickingvegas@gmail.com")) :maintainer '("Charles Choi" . "kickingvegas@gmail.com") :keywords '("tools" "wp") :url "https://github.com/kickingvegas/casual")
